@@ -5,6 +5,7 @@ from django.utils.translation import get_language
 from django.utils.translation import ugettext_lazy as _
 
 from cmsplugin_blog.admin import M2MPlaceholderAdmin
+from django_libs.admin import MultilingualPublishMixin
 from simple_translation.admin import TranslationAdmin
 from simple_translation.utils import get_preferred_translation_from_lang
 
@@ -27,10 +28,11 @@ class DocumentCategoryAdmin(TranslationAdmin):
     title.short_description = _('Title')
 
 
-class DocumentAdmin(M2MPlaceholderAdmin):
+class DocumentAdmin(MultilingualPublishMixin, M2MPlaceholderAdmin):
     """Admin class for the ``Document`` model."""
     list_display = [
-        'title', 'position', 'user', 'is_on_front_page', 'languages', ]
+        'title', 'position', 'user', 'is_on_front_page', 'languages',
+        'is_published']
 
     def title(self, obj):
         lang = get_language()
